@@ -1,4 +1,3 @@
-# $Id$
 
 package Data::Feed::RSS::Entry;
 use Any::Moose;
@@ -36,6 +35,11 @@ sub link {
     }
 }
 
+sub links {
+    my $item = shift->entry;
+    return ( $item->{link} );
+}
+
 sub summary {
     my $item = shift->entry;
 
